@@ -25,8 +25,9 @@
 #include "empathy-ft-handler.h"
 
 #include <glib/gi18n-lib.h>
+#include <tp-account-widgets/tpaw-time.h>
+#include <tp-account-widgets/tpaw-utils.h>
 
-#include "empathy-time.h"
 #include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_FT
@@ -601,7 +602,7 @@ check_hash_incoming (EmpathyFTHandler *handler)
   HashingData *hash_data;
   EmpathyFTHandlerPriv *priv = GET_PRIV (handler);
 
-  if (!EMP_STR_EMPTY (priv->content_hash))
+  if (!TPAW_STR_EMPTY (priv->content_hash))
     {
       hash_data = g_slice_new0 (HashingData);
       hash_data->total_bytes = priv->total_bytes;
@@ -643,7 +644,7 @@ update_remaining_time_and_speed (EmpathyFTHandler *handler,
   last_transferred_bytes = priv->transferred_bytes;
   priv->transferred_bytes = transferred_bytes;
 
-  current_time = empathy_time_get_current ();
+  current_time = tpaw_time_get_current ();
   elapsed_time = current_time - priv->last_update_time;
 
   if (elapsed_time >= 1)
@@ -672,7 +673,7 @@ ft_transfer_transferred_bytes_cb (TpFileTransferChannel *channel,
 
   if (priv->transferred_bytes == 0)
     {
-      priv->last_update_time = empathy_time_get_current ();
+      priv->last_update_time = tpaw_time_get_current ();
       g_signal_emit (handler, signals[TRANSFER_STARTED], 0, channel);
     }
 
@@ -1512,7 +1513,7 @@ empathy_ft_handler_incoming_set_destination (EmpathyFTHandler *handler,
   /* check if hash is supported. if it isn't, set use_hash to FALSE
    * anyway, so that clients won't be expecting us to checksum.
    */
-  if (EMP_STR_EMPTY (priv->content_hash) ||
+  if (TPAW_STR_EMPTY (priv->content_hash) ||
       priv->content_hash_type == TP_FILE_HASH_TYPE_NONE)
     priv->use_hash = FALSE;
   else
