@@ -18,23 +18,18 @@
  */
 
 #include "config.h"
+#include "empathy-chat-manager.h"
 
 #include <telepathy-glib/proxy-subclass.h>
 
-#include <libempathy/empathy-chatroom-manager.h>
-#include <libempathy/empathy-request-util.h>
-#include <libempathy/empathy-individual-manager.h>
-
-#include <libempathy-gtk/empathy-ui-utils.h>
-
+#include "empathy-chatroom-manager.h"
 #include "empathy-chat-window.h"
+#include "empathy-request-util.h"
+#include "empathy-ui-utils.h"
+#include "extensions.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
-
-#include "empathy-chat-manager.h"
-
-#include <extensions/extensions.h>
+#include "empathy-debug.h"
 
 enum {
   CLOSED_CHATS_CHANGED,
