@@ -19,13 +19,8 @@
  */
 
 #include "config.h"
-
 #include "mock-pkcs11.h"
 
-#include <gcr/gcr.h>
-
-#include <glib.h>
-
 #include <string.h>
 
 /*
